==> jooq-codegen-1.6.0-sources.jar: org/jooq/util/GenerationUtil.java <==
/**
 * Copyright (c) 2009-2011, Lukas Eder, lukas.eder@gmail.com
 * All rights reserved.
 *
 * This software is licensed to you under the Apache License, Version 2.0
 * (the "License"); You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * . Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 * . Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * . Neither the name "jOOQ" nor the names of its contributors may be
 *   used to endorse or promote products derived from this software without
 *   specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.jooq.util;

import static org.jooq.impl.FieldTypeHelper.normalise;

import org.jooq.SQLDialect;
import org.jooq.SQLDialectNotSupportedException;
import org.jooq.util.db2.DB2DataType;
import org.jooq.util.derby.DerbyDataType;
import org.jooq.util.h2.H2DataType;
import org.jooq.util.hsqldb.HSQLDBDataType;
import org.jooq.util.ingres.IngresDataType;
import org.jooq.util.mysql.MySQLDataType;
import org.jooq.util.oracle.OracleDataType;
import org.jooq.util.postgres.PostgresDataType;
import org.jooq.util.sqlite.SQLiteDataType;
import org.jooq.util.sqlserver.SQLServerDataType;
import org.jooq.util.sybase.SybaseDataType;

class GenerationUtil {

    /**
     * Take a literal (e.g. database column) and make it a Java identifier
     */
    static String convertToJavaIdentifier(String literal) {
        StringBuilder sb = new StringBuilder();

        if ("".equals(literal)) {
            return "_";
        }

        if (!Character.isJavaIdentifierStart(literal.charAt(0))) {
            sb.append("_");
        }

        for (int i = 0; i < literal.length(); i++) {
            char c = literal.charAt(i);

            if (!Character.isJavaIdentifierPart(c)) {
                sb.append("_");
            }
            else {
                sb.append(c);
            }
        }

        return sb.toString();
    }

    /**
     * Take a qualified Java type and make it a simple type
     *
     * @see Class#getSimpleName()
     */
    static String getSimpleJavaType(String qualifiedJavaType) {
        if (qualifiedJavaType == null) {
            return null;
        }

        return qualifiedJavaType.replaceAll(".*\\.", "");
    }

    /**
     * Convert a type name (using precision and scale) into a Java class
     */
    static Class<?> getDialectSQLType(SQLDialect dialect, String t, int p, int s) throws SQLDialectNotSupportedException {
        switch (dialect) {
            case DB2:
                return DB2DataType.getDataType(normalise(t)).getType();
            case DERBY:
                return DerbyDataType.getDataType(normalise(t)).getType();
            case H2:
                return H2DataType.getDataType(normalise(t)).getType();
            case HSQLDB:
                return HSQLDBDataType.getDataType(normalise(t)).getType();
            case INGRES:
                return IngresDataType.getDataType(normalise(t)).getType();
            case MYSQL:
                return MySQLDataType.getDataType(normalise(t)).getType();
            case ORACLE:
                return OracleDataType.getDataType(normalise(t)).getType(p, s);
            case POSTGRES:
                return PostgresDataType.getDataType(normalise(t)).getType();
            case SQLITE:
                return SQLiteDataType.getDataType(normalise(t)).getType();
            case SQLSERVER:
                return SQLServerDataType.getDataType(normalise(t)).getType();
            case SYBASE:
                return SybaseDataType.getDataType(normalise(t)).getType();
            default:
                throw new SQLDialectNotSupportedException("This method is not yet implemented for dialect " + dialect);
        }
    }

    /**
     * Gets the base type for an array type, depending on the RDBMS dialect
     */
    static String getArrayBaseType(SQLDialect dialect, String t, String u) {
        switch (dialect) {
            case POSTGRES: {

                // The convention is to prepend a "_" to a type to get an array type
                if (u != null && u.startsWith("_")) {
                    return u.substring(1);
                }

                // But there are also arrays with a "vector" suffix
                else {
                    return u;
                }
            }

            case H2: {
                return H2DataType.OTHER.getTypeName();
            }

            case HSQLDB: {
                return t.replace(" ARRAY", "");
            }
        }

        throw new SQLDialectNotSupportedException("getArrayBaseType() is not supported for dialect " + dialect);
    }
}

==> jooq-codegen-1.6.1-sources.jar: org/jooq/util/GenerationUtil.java <==
/**
 * Copyright (c) 2009-2011, Lukas Eder, lukas.eder@gmail.com
 * All rights reserved.
 *
 * This software is licensed to you under the Apache License, Version 2.0
 * (the "License"); You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * . Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 * . Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * . Neither the name "jOOQ" nor the names of its contributors may be
 *   used to endorse or promote products derived from this software without
 *   specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.jooq.util;

import static org.jooq.impl.FieldTypeHelper.normalise;

import java.sql.Types;

import org.jooq.DataType;
import org.jooq.SQLDialect;
import org.jooq.SQLDialectNotSupportedException;
import org.jooq.impl.FieldTypeHelper;
import org.jooq.util.db2.DB2DataType;
import org.jooq.util.derby.DerbyDataType;
import org.jooq.util.h2.H2DataType;
import org.jooq.util.hsqldb.HSQLDBDataType;
import org.jooq.util.ingres.IngresDataType;
import org.jooq.util.mysql.MySQLDataType;
import org.jooq.util.oracle.OracleDataType;
import org.jooq.util.postgres.PostgresDataType;
import org.jooq.util.sqlite.SQLiteDataType;
import org.jooq.util.sqlserver.SQLServerDataType;
import org.jooq.util.sybase.SybaseDataType;

class GenerationUtil {

    /**
     * Take a literal (e.g. database column) and make it a Java identifier
     */
    static String convertToJavaIdentifier(String literal) {
        StringBuilder sb = new StringBuilder();

        if ("".equals(literal)) {
            return "_";
        }

        if (!Character.isJavaIdentifierStart(literal.charAt(0))) {
            sb.append("_");
        }

        for (int i = 0; i < literal.length(); i++) {
            char c = literal.charAt(i);

            if (!Character.isJavaIdentifierPart(c)) {
                sb.append("_");
            }
            else {
                sb.append(c);
            }
        }

        return sb.toString();
    }

    /**
     * Take a qualified Java type and make it a simple type
     *
     * @see Class#getSimpleName()
     */
    static String getSimpleJavaType(String qualifiedJavaType) {
        if (qualifiedJavaType == null) {
            return null;
        }

        return qualifiedJavaType.replaceAll(".*\\.", "");
    }

    /**
     * Convert a type name (using precision and scale) into a Java class
     */
    static DataType<?> getDialectDataType(SQLDialect dialect, String t, int p, int s) throws SQLDialectNotSupportedException {
        switch (dialect) {
            case DB2:
                return DB2DataType.getDataType(normalise(t));
            case DERBY:
                return DerbyDataType.getDataType(normalise(t));
            case H2:
                return H2DataType.getDataType(normalise(t));
            case HSQLDB:
                return HSQLDBDataType.getDataType(normalise(t));
            case INGRES:
                return IngresDataType.getDataType(normalise(t));
            case MYSQL:
                return MySQLDataType.getDataType(normalise(t));
            case ORACLE: {
                DataType<?> dataType = OracleDataType.getDataType(normalise(t));

                if (dataType == OracleDataType.NUMBER) {
                    dataType = OracleDataType.getDataType(FieldTypeHelper.getClass(Types.NUMERIC, p, s));
                }

                return dataType;
            }
            case POSTGRES:
                return PostgresDataType.getDataType(normalise(t));
            case SQLITE:
                return SQLiteDataType.getDataType(normalise(t));
            case SQLSERVER:
                return SQLServerDataType.getDataType(normalise(t));
            case SYBASE:
                return SybaseDataType.getDataType(normalise(t));
            default:
                throw new SQLDialectNotSupportedException("This method is not yet implemented for dialect " + dialect);
        }
    }

    /**
     * Convert a type name (using precision and scale) into a Java class
     */
    static Class<?> getDialectJavaType(SQLDialect dialect, String t, int p, int s) throws SQLDialectNotSupportedException {
        return getDialectDataType(dialect, t, p, s).getType(p, s);
    }

    /**
     * Gets the base type for an array type, depending on the RDBMS dialect
     */
    static String getArrayBaseType(SQLDialect dialect, String t, String u) {
        switch (dialect) {
            case POSTGRES: {

                // The convention is to prepend a "_" to a type to get an array type
                if (u != null && u.startsWith("_")) {
                    return u.substring(1);
                }

                // But there are also arrays with a "vector" suffix
                else {
                    return u;
                }
            }

            case H2: {
                return H2DataType.OTHER.getTypeName();
            }

            case HSQLDB: {
                return t.replace(" ARRAY", "");
            }
        }

        throw new SQLDialectNotSupportedException("getArrayBaseType() is not supported for dialect " + dialect);
    }
}
